[empathy] chat_window_new_message_cb: update the window icon as well (#558802)



commit 744a7afc76aba311c63ba8e7f6cced9d538da42a
Author: Guillaume Desmottes <guillaume desmottes collabora co uk>
Date:   Mon Sep 20 16:30:06 2010 +0200

    chat_window_new_message_cb: update the window icon as well (#558802)
    
    We want to change the window icon even if it's not focused.

 src/empathy-chat-window.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
---
diff --git a/src/empathy-chat-window.c b/src/empathy-chat-window.c
index dd87236..4b181d3 100644
--- a/src/empathy-chat-window.c
+++ b/src/empathy-chat-window.c
@@ -1428,8 +1428,9 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 		chat_window_show_or_update_notification (window, message, chat);
 	}
 
 	/* update the number of unread messages */
 	chat_window_title_update (priv);
+	chat_window_icon_update (priv);
 }
 
 static GtkNotebook *
@@ -1428,8 +1428,9 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 	}
 
-	/* update the number of unread messages */
+	/* update the number of unread messages and the window icon */
 	chat_window_title_update (priv);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]